__name__ = "chkpkg",
__version__ = '0.3.1'
__author__ = "Artёm IG"
__author_email__ = "ortemeo@gmail.com"
__license__ = "MIT"
__summary__ = "Tests Python package sources to see if they build " \
              "successfully to a PyPi compatible distribution"
__keywords__ = "package packaging distribution wheel whl " \
               "testing setup build setuptools twine pypi qa ci".split()

